@@ -342,7 +342,7 @@ update_frame_state (struct cursor *c)
 }
 
 
-PROTECTED int
+int
 unw_step (unw_cursor_t *cursor)
 {
   struct cursor *c = (struct cursor *) cursor;
